{ config, pkgs, lib, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
      ../../configuration/common
      ../../configuration/proxmox-vm
    ];

  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  boot.loader.grub.device = "/dev/vda";

  networking.hostName = "nonat";

  networking.useDHCP = false;
  networking.interfaces.ens18.ipv4.addresses = [
    { address = "141.24.46.169"; prefixLength = 24; }
  ];
  networking.interfaces.ens18.ipv6.addresses = [
    { address = "2001:638:904:ffca::6"; prefixLength = 64; }
  ];
  networking.defaultGateway = { address = "141.24.46.1"; interface = "ens18"; };
  networking.defaultGateway6 = { address = "2001:638:904:ffca::1"; interface = "ens18"; };
  networking.nameservers = [ "2001:638:904:ffcc::3" "2001:638:904:ffcc::4" "141.24.40.3" "141.24.40.4" ];

  networking.interfaces.ens19.ipv4.addresses = [
    { address = "192.168.10.1"; prefixLength = 24; }
  ];
  networking.nat = {
    enable = true;
    externalInterface = "ens18";
    externalIP = (lib.head config.networking.interfaces.ens18.ipv4.addresses).address;
    internalInterfaces = [ "ens19" ];
    internalIPs = [
      (lib.head config.networking.interfaces.ens19.ipv4.addresses).address
    ];
  };

  networking.wireguard.enable = true;
  networking.wireguard.interfaces = {
    wg-porter = {
      peers = [ {
          allowedIPs = [ "0.0.0.0/0" "::/0" ];
          endpoint = "porter.net.clerie.de:51337";
          publicKey = "TzQV60SvPZuJ9yTzvyGwejyXw1SlKkilS4UUvrQcyGk=";
      } ];
      listenPort = 51337;
      allowedIPsAsRoutes = false;
      privateKeyFile = "/var/src/secrets/wireguard/wg-porter";
    } // (import ../../lib/link-local-wireguard.nix {}).llIPv6 "fe80::1337:2" "fe80::1337:1" "wg-porter";
  };

  networking.firewall.allowedUDPPorts = [ 51337 ];

  system.stateVersion = "21.03";
}
